#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-2f0f191d550c98d883484a26718721e3
key: netwo_Fw88IDYS2EW7ENvFzF024g
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
exposed: True
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/network-protocol-xmpp-0.4.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-Fw88IDYS2EW7ENvFzF024g
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    gnuidn-0.2.2-0ffa51594095a53764b8bdc650dc6fa5
    gnutls-0.2-8df9baa3e646be4b43083fa069a940a0
    gsasl-0.3.6-675ae69617ad67a14a7dd583e0c2e57a
    libxml-sax-0.7.5-5224794631ed64ec66d4738f6368afe2
    monads-tf-0.1.0.2-fdcac0b12e43d8f2d2c7bd2854843ca0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
